// パラメータの型を定義します。
type ParameterDefinition = {
  // message1 と message2 のパラメータを持ちます。
  message1: UIContainerActionParameterDefinitionType;
  message2: UIContainerActionParameterDefinitionType;
};

export class MyShowAlertActionItem implements IUIContainerActionItemCore {
  // アクションアイテムの ID となる文字列を返却します。
  public get actionTypeName(): string {
    // 今回はクラス名をそのまま返却する実装とします。
    return MyShowAlertActionItem.name;
  }

  // アクションアイテムの説明ラベルのメッセージキーを返却します。
  public get messageKey(): string {
    return 'CAP.Z.IWP.HICHEE.ACTION.ITEM.LABEL.MyShowAlertActionItem';
  }

  // アクションアイテムのパラメータの定義を返却します。
  public get parameterDefinition(): ParameterDefinition {
    // ParameterDefinition 型で返却する必要があります。
    return {
      message1: {
        type: 'literal', // 固定文字列で指定したい場合
        messageKey: 'CAP.Z.IWP.HICHEE.ACTION.ITEM.LABEL.MyShowAlertActionItem.message1',
      },
      message2: {
        type: 'variable-all', // 変数でしたい場合
        messageKey: 'CAP.Z.IWP.HICHEE.ACTION.ITEM.LABEL.MyShowAlertActionItem.message2',
      },
    };
  }

  // アクションアイテムが実行されたときの処理を記述します。
  public async run(
    context: IUIContainerActionContext,
    container: IUIContainer,
    component: IUIComponent,
    parameters: IUIContainerActionParameterAccessor<ParameterDefinition>
  ): Promise<void> {
    // アクションアイテムのパラメータを文字列で取得します。
    const message1 = parameters.getParameter('message1').toArgument(container).toString();
    const message2 = parameters.getParameter('message2').toArgument(container).toString();

    window.alert(`${message1}\n${message2}`);
  }
}