const path = require("path");
const fs = require("fs");
const glob = require("glob-all");
const UglifyJsPlugin = require("uglifyjs-webpack-plugin");
const StringReplacePlugin = require("string-replace-webpack-plugin");

const REPLACE_TARGET = /IM-HICHEE-PATH-PREFIX\//g;
const REPLACEMENT = "im_bloommaker_programming_sample/";

const registerMessageMap = {};
glob.sync(["**/*.properties", "!node_modules/**/*"]).forEach(path => {
  const buffer = fs.readFileSync(path, { encoding: "UTF-8" }).toString();
  const lines = buffer
    .replace(/ *\\\r?\n */gm, "")
    .split(/(\r?\n)+/m)
    .map(line => line.replace(/[\r\n]/g, ""))
    .filter(line => !!line);
  const localeId = /_([a-z]{2}(_[A-Z]{2})?)\.properties$/.exec(path)
    ? RegExp.$1
    : "standard";

  const messages = registerMessageMap[localeId] || [];
  registerMessageMap[localeId] = messages.concat(lines);
});

module.exports = env => {
  const envLocale = env && env.locale;
  const outputMessages = envLocale ? {} : registerMessageMap;

  if (typeof envLocale === "string") {
    outputMessages[envLocale] = registerMessageMap[envLocale];
  }

  const outputMessagesJSON = JSON.stringify({
    localeId: envLocale,
    messages: outputMessages
  })
    .replace(/\'/g, "\\'")
    .replace(/\"/g, '\\"');

  return {
    context: path.resolve(__dirname, "src"),
    entry: {
      im_bloommaker_programming_sample: "./index"
    },
    output: {
      // bundle.js の出力先
      path: path.resolve(__dirname, "./../public/im_hichee"),
      filename: "[name].bundle.js"
    },
    stats: {
      reasons: true
    },
    resolve: {
      extensions: [".ts", ".js"],
      modules: [path.resolve(__dirname, "src"), "node_modules"]
    },
    optimization: {
      minimizer: [
        new UglifyJsPlugin({
          cache: true,
          parallel: true,
          uglifyOptions: {
            keep_classnames: true,
            keep_fnames: true
          }
        })
      ]
    },
    module: {
      rules: [
        {
          test: /\.js$/,
          exclude: /node_modules/
        },
        {
          test: /\.tsx?$/,
          exclude: /node_modules/,
          use: [
            {
              loader: StringReplacePlugin.replace({
                replacements: [
                  {
                    pattern: "6549e165-925d-4de2-8c52-ec3cda282ed2",
                    replacement: () => outputMessagesJSON
                  },
                  {
                    pattern: REPLACE_TARGET,
                    replacement: () => REPLACEMENT
                  }
                ]
              })
            },
            {
              loader: "ts-loader"
            }
          ]
        },
        {
          test: /\.css/,
          use: [
            "style-loader",
            {
              loader: "css-loader",
              options: {
                url: false,
                sourceMap: false
              }
            }
          ]
        }
      ]
    }
  };
};
